{ config
, lib
, ...
}: {
  programs.plasma = {
    enable = true;
    overrideConfig = true; # needed for stylix compat sadly
    workspace = {
      theme = "breeze-dark";
      lookAndFeel = "org.kde.breezedark.desktop";
      wallpaper = config.stylix.image;
      # wallpaper = "${config.home.homeDirectory}/Pictures/default_background.png"; set by stylix
    };
    panels = [
      # Windows-like panel at the bottom
      {
        location = "bottom";
        screen = "all";
        height = 42;
        widgets = [
          {
            name = "org.kde.plasma.kicker";
            config = {
              General = {
                icon = "nix-snowflake";
                alphaSort = true;
                showIconsRootLevel = true;
              };
            };
          }
          {
            name = "org.kde.plasma.pager";
            config = {
              General = {
                displayedText = "None";
                showWindowIcons = true;
                showOnlyCurrentScreen = true;
                wrapPage = true;
                currentDesktopSelected = "ShowDesktop";
              };
            };
          }
          {
            name = "org.kde.plasma.taskmanager";
            config = {
              General = {
                launchers = [
                  "applications:systemsettings.desktop"
                  "preferred://filemanager"
                  "preferred://browser"
                  "applications:Alacritty.desktop"
                  "applications:emacsclient.desktop"
                ];
              };
            };
          }
          "org.kde.plasma.marginsseparator"
          {
            systemTray.items = {
              shown = [
                "org.kde.plasma.bluetooth"
                "org.kde.plasma.volume"
                "org.kde.plasma.networkmanagement"
                "org.kde.plasma.battery"
              ];
              hidden = [ ];
            };
          }
          {
            digitalClock = {
              calendar.firstDayOfWeek = "monday";
              time.format = "24h";
            };
          }
        ];
        hiding = "none";
      }
      # Application name, Global menu and Song information and playback controls at the top
      {
        location = "top";
        screen = "all";
        height = 26;
        widgets = [
          {
            applicationTitleBar = {
              behavior = {
                activeTaskSource = "activeTask";
              };
              layout = {
                elements = [ "windowTitle" ];
                horizontalAlignment = "left";
                showDisabledElements = "deactivated";
                verticalAlignment = "center";
              };
              overrideForMaximized.enable = false;
              titleReplacements = [
                {
                  type = "regexp";
                  originalTitle = "^Brave Web Browser$";
                  newTitle = "Brave";
                }
                {
                  type = "regexp";
                  originalTitle = ''\\bDolphin\\b'';
                  newTitle = "File manager";
                }
              ];
              windowTitle = {
                font = {
                  bold = false;
                  fit = "fixedSize";
                  size = 13;
                };
                hideEmptyTitle = true;
                undefinedWindowTitle = "";
                margins = {
                  bottom = 0;
                  left = 10;
                  right = 5;
                  top = 0;
                };
                source = "appName";
              };
            };
          }
          "org.kde.plasma.appmenu"
          "org.kde.plasma.panelspacer"
          {
            plasmusicToolbar = {
              panelIcon = {
                albumCover = {
                  useAsIcon = true;
                  radius = 0;
                };
                # icon = "view-media-track";
              };
              playbackSource = "spotify";
              musicControls.showPlaybackControls = true;
              songText = {
                displayInSeparateLines = false;
                maximumWidth = 640;
                scrolling = {
                  behavior = "alwaysScroll";
                  speed = 3;
                };
              };
            };
          }
        ];
      }
    ];
    shortcuts = {
      "KDE Keyboard Layout Switcher"."Switch to Next Keyboard Layout" = "Meta+Alt+K";
      "kaccess"."Toggle Screen Reader On and Off" = "Meta+Alt+S";
      "kcm_touchpad"."Disable Touchpad" = "Touchpad Off";
      "kcm_touchpad"."Enable Touchpad" = "Touchpad On";
      "kcm_touchpad"."Toggle Touchpad" = [ "Touchpad Toggle" "Meta+Ctrl+Zenkaku Hankaku" ];
      "kded5"."Show System Activity" = "Ctrl+Esc";
      "kded5"."display" = [ "Display" "Meta+P" ];
      "kmix"."decrease_microphone_volume" = "Microphone Volume Down";
      "kmix"."decrease_volume" = "Volume Down";
      "kmix"."decrease_volume_small" = "Shift+Volume Down";
      "kmix"."increase_microphone_volume" = "Microphone Volume Up";
      "kmix"."increase_volume" = "Volume Up";
      "kmix"."increase_volume_small" = "Shift+Volume Up";
      "kmix"."mic_mute" = [ "Microphone Mute" "Meta+Volume Mute" ];
      "kmix"."mute" = "Volume Mute";
      "ksmserver"."Lock Session" = [ "Meta+L" "Screensaver" ];
      "ksmserver"."Log Out" = "Ctrl+Alt+Del";
      "kwin"."Activate Window Demanding Attention" = "Meta+Ctrl+A";
      "kwin"."ClearLastMouseMark" = "Meta+Shift+F12";
      "kwin"."ClearMouseMarks" = "Meta+Shift+F11";
      "kwin"."Cube" = [ "Meta+C" "Meta+Space" ];
      "kwin"."Edit Tiles" = "Meta+T";
      "kwin"."Expose" = "Ctrl+F9";
      "kwin"."ExposeAll" = [ "Ctrl+F10" "Launch (C)" ];
      "kwin"."ExposeClass" = "Ctrl+F7";
      "kwin"."Grid View" = "Meta+G";
      "kwin"."Invert" = "Meta+Ctrl+I";
      "kwin"."InvertWindow" = "Meta+Ctrl+U";
      "kwin"."Kill Window" = "Meta+Ctrl+Esc";
      "kwin"."MoveMouseToCenter" = "Meta+F6";
      "kwin"."MoveMouseToFocus" = "Meta+F5";
      "kwin"."Overview" = "Meta+W";
      "kwin"."Show Desktop" = "Meta+D";
      "kwin"."ShowDesktopGrid" = "Meta+F8";
      "kwin"."Suspend Compositing" = "Alt+Shift+F12";
      "kwin"."Switch Window Down" = "Meta+Alt+Down";
      "kwin"."Switch Window Left" = "Meta+Alt+Left";
      "kwin"."Switch Window Right" = "Meta+Alt+Right";
      "kwin"."Switch Window Up" = "Meta+Alt+Up";
      "kwin"."Switch One Desktop Down" = "Meta+Ctrl+Down";
      "kwin"."Switch One Desktop Up" = "Meta+Ctrl+Up";
      "kwin"."Switch One Desktop to the Left" = "Meta+Ctrl+Left";
      "kwin"."Switch One Desktop to the Right" = "Meta+Ctrl+Right";
      "kwin"."Switch to Desktop 1" = "Ctrl+F1";
      "kwin"."Switch to Desktop 2" = "Ctrl+F2";
      "kwin"."Switch to Desktop 3" = "Ctrl+F3";
      "kwin"."Switch to Desktop 4" = "Ctrl+F4";
      "kwin"."ToggleCurrentThumbnail" = "Meta+Ctrl+T";
      "kwin"."ToggleMouseClick" = "Meta+*";
      "kwin"."Walk Through Windows" = "Alt+Tab";
      "kwin"."Walk Through Windows (Reverse)" = "Alt+Shift+Backtab";
      "kwin"."Walk Through Windows of Current Application" = "Alt+`";
      "kwin"."Walk Through Windows of Current Application (Reverse)" = "Alt+~";
      "kwin"."Window Close" = "Alt+F4";
      "kwin"."Window Maximize" = "Meta+PgUp";
      "kwin"."Window Minimize" = "Meta+PgDown";
      "kwin"."Window One Desktop Down" = "Meta+Ctrl+Shift+Down";
      "kwin"."Window One Desktop Up" = "Meta+Ctrl+Shift+Up";
      "kwin"."Window One Desktop to the Left" = "Meta+Ctrl+Shift+Left";
      "kwin"."Window One Desktop to the Right" = "Meta+Ctrl+Shift+Right";
      "kwin"."Window Operations Menu" = "Alt+F3";
      "kwin"."Window Quick Tile Bottom" = "Meta+Down";
      "kwin"."Window Quick Tile Left" = "Meta+Left";
      "kwin"."Window Quick Tile Right" = "Meta+Right";
      "kwin"."Window Quick Tile Top" = "Meta+Up";
      "kwin"."Window to Next Screen" = "Meta+Shift+Right";
      "kwin"."Window to Previous Screen" = "Meta+Shift+Left";
      "kwin"."view_actual_size" = "Meta+0";
      "kwin"."view_zoom_in" = [ "Meta++" "Meta+=" ];
      "kwin"."view_zoom_out" = "Meta+-";
      "mediacontrol"."nextmedia" = "Media Next";
      "mediacontrol"."pausemedia" = "Media Pause";
      "mediacontrol"."playpausemedia" = "Media Play";
      "mediacontrol"."previousmedia" = "Media Previous";
      "mediacontrol"."stopmedia" = "Media Stop";
      "org.kde.dolphin.desktop"."_launch" = "Meta+E";
      "org.kde.konsole.desktop"."_launch" = "Ctrl+Alt+T";
      "org.kde.krunner.desktop"."RunClipboard" = "Alt+Shift+F2";
      "org.kde.krunner.desktop"."_launch" = [ "Alt+Space" "Alt+F2" "Search" ];
      "org.kde.plasma.emojier.desktop"."_launch" = [ "Meta+." "Meta+Ctrl+Alt+Shift+Space" ];
      "org.kde.spectacle.desktop"."ActiveWindowScreenShot" = "Meta+Print";
      "org.kde.spectacle.desktop"."FullScreenScreenShot" = "Shift+Print";
      "org.kde.spectacle.desktop"."RectangularRegionScreenShot" = "Meta+Shift+Print";
      "org.kde.spectacle.desktop"."WindowUnderCursorScreenShot" = "Meta+Ctrl+Print";
      "org.kde.spectacle.desktop"."_launch" = "Print";
      "org_kde_powerdevil"."Decrease Keyboard Brightness" = "Keyboard Brightness Down";
      "org_kde_powerdevil"."Decrease Screen Brightness" = "Monitor Brightness Down";
      "org_kde_powerdevil"."Hibernate" = "Hibernate";
      "org_kde_powerdevil"."Increase Keyboard Brightness" = "Keyboard Brightness Up";
      "org_kde_powerdevil"."Increase Screen Brightness" = "Monitor Brightness Up";
      "org_kde_powerdevil"."PowerDown" = "Power Down";
      "org_kde_powerdevil"."PowerOff" = "Power Off";
      "org_kde_powerdevil"."Sleep" = "Sleep";
      "org_kde_powerdevil"."Toggle Keyboard Backlight" = "Keyboard Light On/Off";
      "plasmashell"."activate task manager entry 1" = "Meta+1";
      "plasmashell"."activate task manager entry 2" = "Meta+2";
      "plasmashell"."activate task manager entry 3" = "Meta+3";
      "plasmashell"."activate task manager entry 4" = "Meta+4";
      "plasmashell"."activate task manager entry 5" = "Meta+5";
      "plasmashell"."activate task manager entry 6" = "Meta+6";
      "plasmashell"."activate task manager entry 7" = "Meta+7";
      "plasmashell"."activate task manager entry 8" = "Meta+8";
      "plasmashell"."activate task manager entry 9" = "Meta+9";
      "plasmashell"."clipboard_action" = "Meta+Ctrl+X";
      "plasmashell"."cycle-panels" = "Meta+Alt+P";
      "plasmashell"."manage activities" = "Meta+Q";
      "plasmashell"."next activity" = "Meta+Tab";
      "plasmashell"."previous activity" = "Meta+Shift+Tab";
      "plasmashell"."repeat_action" = "Meta+Ctrl+R";
      "plasmashell"."show dashboard" = "Ctrl+F12";
      "plasmashell"."show-on-mouse-pos" = "Meta+V";
      "plasmashell"."stop current activity" = "Meta+S";
      "systemsettings.desktop"."_launch" = "Tools";
    };
    configFile = {
      "powerdevilrc" = {
        "AC/Display" = {
          TurnOffDisplayIdleTimeoutSec = lib.mkForce (-1);
          TurnOffDisplayWhenIdle = lib.mkForce false;
        };

        "AC/SuspendAndShutdown" = {
          AutoSuspendAction = lib.mkForce 0;
          AutoSuspendIdleTimeoutSec = lib.mkForce 7200;
          LidAction = lib.mkForce 0;
        };
        "Battery/SuspendAndShutdown".SleepMode = lib.mkForce 2;
        "LowBattery/SuspendAndShutdown".SleepMode = lib.mkForce 3;

        "AC/Performance".PowerProfile = lib.mkForce "performance";
        "Battery/Performance".PowerProfile = lib.mkForce "power-saver";
        "LowBattery/Performance".PowerProfile = lib.mkForce "power-saver";
      };
      "baloofilerc"."Basic Settings"."Indexing-Enabled" = false;
      "baloofilerc"."General"."dbVersion".value = 2;
      "baloofilerc"."General"."exclude filters".value = "*~,*.part,*.o,*.la,*.lo,*.loT,*.moc,moc_*.cpp,qrc_*.cpp,ui_*.h,cmake_install.cmake,CMakeCache.txt,CTestTestfile.cmake,libtool,config.status,confdefs.h,autom4te,conftest,confstat,Makefile.am,*.gcode,.ninja_deps,.ninja_log,build.ninja,*.csproj,*.m4,*.rej,*.gmo,*.pc,*.omf,*.aux,*.tmp,*.po,*.vm*,*.nvram,*.rcore,*.swp,*.swap,lzo,litmain.sh,*.orig,.histfile.*,.xsession-errors*,*.map,*.so,*.a,*.db,*.qrc,*.ini,*.init,*.img,*.vdi,*.vbox*,vbox.log,*.qcow2,*.vmdk,*.vhd,*.vhdx,*.sql,*.sql.gz,*.ytdl,*.class,*.pyc,*.pyo,*.elc,*.qmlc,*.jsc,*.fastq,*.fq,*.gb,*.fasta,*.fna,*.gbff,*.faa,po,CVS,.svn,.git,_darcs,.bzr,.hg,CMakeFiles,CMakeTmp,CMakeTmpQmake,.moc,.obj,.pch,.uic,.npm,.yarn,.yarn-cache,__pycache__,node_modules,node_packages,nbproject,.venv,venv,core-dumps,lost+found";
      "baloofilerc"."General"."exclude filters version".value = 8;
      "dolphinrc"."KFileDialog Settings"."Places Icons Auto-resize".value = false;
      "dolphinrc"."KFileDialog Settings"."Places Icons Static Size".value = 22;
      "kactivitymanagerdrc"."activities"."03741afe-0c0e-413a-9f8a-09600a7684e2".value = "Default";
      "kactivitymanagerdrc"."main"."currentActivity".value = "03741afe-0c0e-413a-9f8a-09600a7684e2";

      # Disable broken mousewheel ################3
      # Desk
      "kcminputrc"."Libinput/1671/49433/CHERRY MW 8C ADVANCED"."ScrollFactor" = 0.0;
      "kcminputrc"."Libinput/1671/49433/input-remapper CHERRY MW 8C ADVANCED forwarded"."ScrollFactor" = 0.0;

      # FW16
      "kcminputrc"."Libinput/1130/49431/Cherry GmbH CHERRY Wireless Device Mouse"."ScrollFactor" = 0.0;
      "kcminputrc"."Libinput/1130/49431/Cherry GmbH CHERRY Wireless Device Consumer Control"."ScrollFactor" = 0.0; # ?
      "kcminputrc"."Libinput/1130/49431/input-remapper Cherry GmbH CHERRY Wireless Device Mouse forwarded"."ScrollFactor" = 0.0;
      # Note: needs input-remapper transient conf to make mouse buttons do mw job
      # TODO nixify input-remapper foo
      ############################################3

      "kcminputrc"."Libinput.2362.597.UNIW0001:00 093A:0255 Touchpad"."ClickMethod".value = 2;
      "kcminputrc"."Libinput.2362.597.UNIW0001:00 093A:0255 Touchpad"."Enabled".value = true;
      "kcminputrc"."Libinput.2362.597.UNIW0001:00 093A:0255 Touchpad"."TapToClick".value = true;
      "kcminputrc"."Mouse"."X11LibInputXAccelProfileFlat".value = false;
      "kcminputrc"."Tmp"."update_info".value = "delete_cursor_old_default_size.upd:DeleteCursorOldDefaultSize";
      "kded5rc"."Module-appmenu"."autoload".value = true;
      "kded5rc"."Module-baloosearchmodule"."autoload".value = true;
      "kded5rc"."Module-bluedevil"."autoload".value = true;
      "kded5rc"."Module-browserintegrationreminder"."autoload".value = false;
      "kded5rc"."Module-colorcorrectlocationupdater"."autoload".value = true;
      "kded5rc"."Module-device_automounter"."autoload".value = false;
      "kded5rc"."Module-freespacenotifier"."autoload".value = true;
      "kded5rc"."Module-gtkconfig"."autoload".value = true;
      "kded5rc"."Module-inotify"."autoload".value = true;
      "kded5rc"."Module-kded_touchpad"."autoload".value = true;
      "kded5rc"."Module-keyboard"."autoload".value = true;
      "kded5rc"."Module-khotkeys"."autoload".value = true;
      "kded5rc"."Module-kscreen"."autoload".value = true;
      "kded5rc"."Module-ksysguard"."autoload".value = true;
      "kded5rc"."Module-ktimezoned"."autoload".value = true;
      "kded5rc"."Module-networkmanagement"."autoload".value = true;
      "kded5rc"."Module-networkstatus"."autoload".value = true;
      "kded5rc"."Module-plasma_accentcolor_service"."autoload".value = true;
      "kded5rc"."Module-printmanager"."autoload".value = true;
      "kded5rc"."Module-proxyscout"."autoload".value = true;
      "kded5rc"."Module-remotenotifier"."autoload".value = true;
      "kded5rc"."Module-smbwatcher"."autoload".value = true;
      "kded5rc"."Module-statusnotifierwatcher"."autoload".value = true;
      "kded5rc"."PlasmaBrowserIntegration"."shownCount".value = 4;
      "kdeglobals"."General"."TerminalApplication".value = "alacritty";
      "kdeglobals"."General"."TerminalService".value = "Alacritty.desktop";
      "kdeglobals"."General"."AccentColor".value = "233,100,58";
      "kdeglobals"."General"."BrowserApplication".value = "firefox.desktop";
      "kdeglobals"."General"."LastUsedCustomAccentColor".value = "233,100,58";
      "kdeglobals"."General"."XftHintStyle".value = "hintmedium";
      "kdeglobals"."General"."XftSubPixel".value = "rgb";
      "kdeglobals"."General"."font".value = "Iosevka Nerd Font Propo,11,-1,5,63,0,0,0,0,0,SemiBold";
      "kdeglobals"."General"."fixed".value = "Iosevka Nerd Font Mono,10,-1,5,50,0,0,0,0,0";
      "kdeglobals"."General"."menuFont".value = "Iosevka Nerd Font Propo,11,-1,5,63,0,0,0,0,0,SemiBold";
      "kdeglobals"."General"."smallestReadableFont".value = "Iosevka Nerd Font Propo,8,-1,5,63,0,0,0,0,0,SemiBold";
      "kdeglobals"."General"."toolBarFont".value = "Iosevka Nerd Font Propo,11,-1,5,63,0,0,0,0,0,SemiBold";
      "kdeglobals"."KDE"."AnimationDurationFactor".value = 0.35;
      "kdeglobals"."KDE"."SingleClick".value = true;
      "kdeglobals"."KDE"."widgetStyle".value = "Breeze";
      "kdeglobals"."KFileDialog Settings"."Allow Expansion".value = false;
      "kdeglobals"."KFileDialog Settings"."Automatically select filename extension".value = true;
      "kdeglobals"."KFileDialog Settings"."Breadcrumb Navigation".value = false;
      "kdeglobals"."KFileDialog Settings"."Decoration position".value = 2;
      "kdeglobals"."KFileDialog Settings"."LocationCombo Completionmode".value = 5;
      "kdeglobals"."KFileDialog Settings"."PathCombo Completionmode".value = 5;
      "kdeglobals"."KFileDialog Settings"."Show Bookmarks".value = false;
      "kdeglobals"."KFileDialog Settings"."Show Full Path".value = false;
      "kdeglobals"."KFileDialog Settings"."Show Inline Previews".value = true;
      "kdeglobals"."KFileDialog Settings"."Show Preview".value = false;
      "kdeglobals"."KFileDialog Settings"."Show Speedbar".value = true;
      "kdeglobals"."KFileDialog Settings"."Show hidden files".value = true;
      "kdeglobals"."KFileDialog Settings"."Sort by".value = "Name";
      "kdeglobals"."KFileDialog Settings"."Sort directories first".value = true;
      "kdeglobals"."KFileDialog Settings"."Sort hidden files last".value = false;
      "kdeglobals"."KFileDialog Settings"."Sort reversed".value = false;
      "kdeglobals"."KFileDialog Settings"."Speedbar Width".value = 138;
      "kdeglobals"."KFileDialog Settings"."View Style".value = "DetailTree";
      "kdeglobals"."KShortcutsDialog Settings"."Dialog Size".value = "600,480";
      "kdeglobals"."WM"."activeBackground".value = "39,39,39";
      "kdeglobals"."WM"."activeBlend".value = "235,219,178";
      "kdeglobals"."WM"."activeForeground".value = "235,219,178";
      "kdeglobals"."WM"."inactiveBackground".value = "40,40,40";
      "kdeglobals"."WM"."inactiveBlend".value = "60,56,54";
      "kdeglobals"."WM"."inactiveForeground".value = "204,190,155";
      "kglobalshortcutsrc"."ActivityManager"."_k_friendly_name".value = "Activity Manager";
      "kglobalshortcutsrc"."KDE Keyboard Layout Switcher"."_k_friendly_name".value = "Keyboard Layout Switcher";
      "kglobalshortcutsrc"."kaccess"."_k_friendly_name".value = "Accessibility";
      "kglobalshortcutsrc"."kcm_touchpad"."_k_friendly_name".value = "Touchpad";
      "kglobalshortcutsrc"."kded5"."_k_friendly_name".value = "KDE Daemon";
      "kglobalshortcutsrc"."khotkeys"."_k_friendly_name".value = "Custom Shortcuts Service";
      "kglobalshortcutsrc"."kmix"."_k_friendly_name".value = "Audio Volume";
      "kglobalshortcutsrc"."ksmserver"."_k_friendly_name".value = "Session Management";
      "kglobalshortcutsrc"."kwin"."_k_friendly_name".value = "KWin";
      "kglobalshortcutsrc"."mediacontrol"."_k_friendly_name".value = "Media Controller";
      "kglobalshortcutsrc"."org.kde.dolphin.desktop"."_k_friendly_name".value = "Dolphin";
      "kglobalshortcutsrc"."org.kde.konsole.desktop"."_k_friendly_name".value = "Konsole";
      "kglobalshortcutsrc"."org.kde.krunner.desktop"."_k_friendly_name".value = "KRunner";
      "kglobalshortcutsrc"."org.kde.plasma.emojier.desktop"."_k_friendly_name".value = "Emoji Selector";
      "kglobalshortcutsrc"."org.kde.spectacle.desktop"."_k_friendly_name".value = "Spectacle";
      "kglobalshortcutsrc"."org_kde_powerdevil"."_k_friendly_name".value = "Power Management";
      "kglobalshortcutsrc"."plasmashell"."_k_friendly_name".value = "Plasma";
      "kglobalshortcutsrc"."systemsettings.desktop"."_k_friendly_name".value = "System Settings";
      "kiorc"."Confirmations"."ConfirmDelete".value = false;
      "kiorc"."Confirmations"."ConfirmEmptyTrash".value = false;
      "ksplashrc"."KSplash"."Engine".value = "none";
      "kwalletrc"."Auto Allow"."kdewallet".value = "kded5,kiod5,kwalletmanager5,Brave,Nextcloud";
      "kwalletrc"."Wallet"."Close When Idle".value = false;
      "kwalletrc"."Wallet"."Close on Screensaver".value = false;
      "kwalletrc"."Wallet"."Default Wallet".value = "kdewallet";
      "kwalletrc"."Wallet"."Enabled".value = true;
      "kwalletrc"."Wallet"."First Use".value = false;
      "kwalletrc"."Wallet"."Idle Timeout".value = 10;
      "kwalletrc"."Wallet"."Launch Manager".value = true;
      "kwalletrc"."Wallet"."Leave Manager Open".value = false;
      "kwalletrc"."Wallet"."Leave Open".value = true;
      "kwalletrc"."Wallet"."Prompt on Open".value = true;
      "kwalletrc"."Wallet"."Use One Wallet".value = true;
      "kwalletrc"."org.freedesktop.secrets"."apiEnabled".value = true;
      "kwinrc"."Compositing"."LatencyPolicy".value = "Medium";
      "kwinrc"."Desktops"."Id_1".value = "6b86c814-0a63-4a66-83aa-8f923109b8dc";
      "kwinrc"."Desktops"."Id_2".value = "51266a99-9eeb-4a62-a7f1-8b9ddedc5296";
      "kwinrc"."Desktops"."Id_3".value = "7b7d4799-86fe-4b40-8951-1eac646f2707";
      "kwinrc"."Desktops"."Id_4".value = "686aa552-08df-4324-89fd-6f327fc70802";
      "kwinrc"."Desktops"."Id_5".value = "4bed024c-ec67-426b-8155-30ea753b0bda";
      "kwinrc"."Desktops"."Id_6".value = "dd242c1f-ba7d-4660-96ee-2e39899021bb";
      "kwinrc"."Desktops"."Id_7".value = "f9c5fd26-edbc-4d01-9c81-2ea3902c298a";
      "kwinrc"."Desktops"."Id_8".value = "872f161b-e13e-41eb-a46d-41934fe09083";
      "kwinrc"."Desktops"."Id_9".value = "223607a5-d111-4e70-94a7-0f989dfd53d4";
      "kwinrc"."Desktops"."Number".value = 9;
      "kwinrc"."Desktops"."Rows".value = 3;
      "kwinrc"."Effect-cube"."BorderActivate".value = 5;
      "kwinrc"."Effect-cube"."DistanceFactor".value = 1.65;
      "kwinrc"."Plugins"."cubeEnabled".value = true;
      "kwinrc"."Plugins"."desktopchangeosdEnabled".value = true;
      "kwinrc"."Plugins"."glideEnabled".value = true;
      "kwinrc"."Plugins"."scaleEnabled".value = false;
      "kwinrc"."Plugins"."shakecursorEnabled".value = true;
      "kwinrc"."Plugins"."kwin4_effect_fadeEnabled".value = true;
      "kwinrc"."Plugins"."kwin4_effect_scaleEnabled".value = false;
      "kwinrc"."Plugins"."kwin4_effect_squashEnabled".value = false;
      "kwinrc"."Plugins"."magiclampEnabled".value = true;
      "kwinrc"."Plugins"."mouseclickEnabled".value = true;
      "kwinrc"."Plugins"."sheetEnabled".value = true;
      "kwinrc"."Plugins"."wobblywindowsEnabled".value = true;
      "kwinrc"."Tiling"."padding".value = 4;
      "kwinrc"."Windows"."RollOverDesktops".value = true;
      "kwinrc"."Xwayland"."Scale".value = 1.25;
      "kxkbrc"."Layout"."Options".value = "caps:ctrl_modifier";
      "kxkbrc"."Layout"."ResetOldOptions".value = true;
      "plasma-localerc"."Formats"."LANG".value = "en_US.UTF-8";
      "plasmarc"."Wallpapers"."usersWallpapers".value = "";
      # "plasmarc"."Theme"."name".value = "breeze-dark";
      "krunnerrc"."General"."FreeFloating".value = true;
      #"kscreenlockerrc"."Greeter.Wallpaper.org.kde.image.General"."Image".value = "/home/tristand/.background";
      #"kscreenlockerrc"."Greeter.Wallpaper.org.kde.image.General"."PreviewImage".value = "/home/tristand/.background"; # TODO rework this with static wallpaper
    };
  };
}
